@@ -27,8 +27,7 @@
 
 LUPDATE_OPTIONS="-no-obsolete"
 LUPDATE_OPTIONS="${LUPDATE_OPTIONS} -locations none "
-TS_FILE="../gui/translations/src.boomaga.ts"
-
+TS_FILE="../src/boomaga/translations/src.boomaga.ts"
 
 LUPDATE=$(which lupdate-qt4 2>/dev/null)
 [ -z "${LUPDATE}" ] && LUPDATE=$(which lupdate-qt5 2>/dev/null)
