@@ -31,7 +31,6 @@
 #include "kernel/job.h"
 #include "kernel/printer.h"
 #include "kernel/layout.h"
-#include "kernel/inputfile.h"
 #include "printersettings/printersettings.h"
 #include "aboutdialog/aboutdialog.h"
 #include "actions.h"
@@ -184,6 +183,9 @@ MainWindow::MainWindow(QWidget *parent):
     connect(ui->menuEditJob, SIGNAL(aboutToShow()),
             this, SLOT(showEditJobMainMenu()));
 
+    connect(project, SIGNAL(longTaskStarted(const ProjectLongTask*)),
+            this , SLOT(longTaskStarted(const ProjectLongTask*)));
+
     ui->preview->setFocusPolicy(Qt::StrongFocus);
     ui->preview->setFocus();
 
@@ -402,6 +404,7 @@ void MainWindow::initActions()
  ************************************************/
 void MainWindow::initStatusBar()
 {
+    ui->statusbar->setStyleSheet("QStatusBar::item{ border: transparent; }");
     ui->statusbar->addPermanentWidget(&mStatusBarCurrentSheetLabel);
 
     ui->statusbar->addPermanentWidget(&mStatusBarSheetsLabel);
@@ -559,6 +562,16 @@ QMessageBox *MainWindow::showPrintDialog(const QString &text)
 }
 
 
+/************************************************
+ *
+ ************************************************/
+void rotateSheets(QList<Sheet*> &sheets)
+{
+    foreach (Sheet *s, sheets)
+        s->setRotation(s->rotation() + Rotate180);
+}
+
+
 /************************************************
 
  ************************************************/
@@ -583,7 +596,6 @@ bool MainWindow::print(uint count, bool collate)
     saveAuto();
 
     bool res = true;
-    bool showDialog = project->printer()->isShowProgressDialog();
     QMessageBox *infoDialog = 0;
 
     bool split = project->doubleSided() &&
@@ -595,6 +607,8 @@ bool MainWindow::print(uint count, bool collate)
         Project::PagesOrder order_2;
         Project::PagesType  pagesType_1;
         Project::PagesType  pagesType_2;
+        bool rotate_1 = false;
+        bool rotate_2 = false;
 
         if (project->printer()->duplexType() == DuplexManual)
         {
@@ -612,6 +626,9 @@ bool MainWindow::print(uint count, bool collate)
                 pagesType_1 = Project::EvenPages;
                 pagesType_2 = Project::OddPages;
             }
+
+            rotate_1 = isLandscape(project->rotation());
+            rotate_2 = false;
         }
         else
         {
@@ -629,12 +646,20 @@ bool MainWindow::print(uint count, bool collate)
                 pagesType_1 = Project::EvenPages;
                 pagesType_2 = Project::OddPages;
             }
-        }
 
+            rotate_1 = isPortrate(project->rotation());
+            rotate_2 = false;
+        }
 
          keeper.sheets_1 = project->selectSheets(pagesType_1, order_1);
          keeper.sheets_2 = project->selectSheets(pagesType_2, order_2);
 
+         if (rotate_1)
+             rotateSheets(keeper.sheets_1);
+
+         if (rotate_2)
+             rotateSheets(keeper.sheets_2);
+
 
          if (keeper.sheets_1.count())
          {
@@ -650,13 +675,13 @@ bool MainWindow::print(uint count, bool collate)
              }
 
 
-             if (showDialog && !keeper.sheets_2.count())
+             if (!keeper.sheets_2.count())
              {
                  infoDialog = showPrintDialog(tr("Print the all pages on %1.").arg(project->printer()->name()));
              }
 
 
-             res = project->printer()->print(keeper.sheets_1, "", false, count, collate);
+             res = project->printer()->print(keeper.sheets_1, "", project->doubleSided(), count, collate);
              if (!res)
              {
                  delete(infoDialog);
@@ -702,10 +727,9 @@ bool MainWindow::print(uint count, bool collate)
                      keeper.sheets_2.append(new Sheet(1, 0));
              }
 
-             if (showDialog)
-                infoDialog = showPrintDialog(tr("Print the even pages on %1.").arg(project->printer()->name()));
+             infoDialog = showPrintDialog(tr("Print the even pages on %1.").arg(project->printer()->name()));
 
-             res = project->printer()->print(keeper.sheets_2, "", false, count, collate);
+             res = project->printer()->print(keeper.sheets_2, "", project->doubleSided(), count, collate);
              if (!res)
              {
                  delete(infoDialog);
@@ -716,8 +740,7 @@ bool MainWindow::print(uint count, bool collate)
     }
     else //if (split) no
     {
-        if (showDialog)
-            infoDialog = showPrintDialog(tr("Print the all pages on %1.").arg(project->printer()->name()));
+        infoDialog = showPrintDialog(tr("Print the all pages on %1.").arg(project->printer()->name()));
 
         Project::PagesOrder order;
         if (project->printer()->reverseOrder())
@@ -794,21 +817,17 @@ void MainWindow::showAboutDialog()
 /************************************************
 
  ************************************************/
-void MainWindow::updateProgressBar(int value, int all)
+void MainWindow::updateProgressBar(int value, int total)
 {
-    if (all <1 && mProgressBar.isVisible())
+    if (total < 0)
     {
         mProgressBar.hide();
         return;
     }
 
-    if (mProgressBar.maximum() != all)
-        mProgressBar.setMaximum(all);
-
+    mProgressBar.setMaximum(total);
     mProgressBar.setValue(value);
-
-    if (all > 0 && mProgressBar.isHidden())
-        mProgressBar.show();
+    mProgressBar.show();
 }
 
 
@@ -826,7 +845,7 @@ void MainWindow::showPreviewContextMenu(Sheet*, ProjectPage *page)
 /************************************************
 
  ************************************************/
-void MainWindow::showJobViewContextMenu(Job job)
+void MainWindow::showJobViewContextMenu(const Job &job)
 {
     QMenu menu;
     fillJobEditMenu(job, &menu);
@@ -969,7 +988,7 @@ void MainWindow::fillPageEditMenu(ProjectPage *page, QMenu *menu)
 /************************************************
  *
  * ***********************************************/
-void MainWindow::fillJobEditMenu(const Job job, QMenu *menu)
+void MainWindow::fillJobEditMenu(const Job &job, QMenu *menu)
 {
     JobAction *act;
 
@@ -1348,25 +1367,28 @@ void MainWindow::exportAs()
  ************************************************/
 void MainWindow::load()
 {
-    QString fileName = QFileDialog::getOpenFileName(
+    QFileDialog dialog(
                 this, this->windowTitle(),
                 settings->value(Settings::SaveDir).toString(),
                 tr("All supported files (*.pdf *.boo);;Boomaga files (*.boo);;PDF files (*.pdf);;All files (*.*)"));
 
-    if (fileName.isEmpty())
-        return;
-    settings->setValue(Settings::SaveDir, QFileInfo(fileName).path());
+    dialog.setFileMode(QFileDialog::ExistingFiles);
+    dialog.selectNameFilter(settings->value(Settings::MainWindow_OpenFileFilter).toString());
 
-    try
-    {
-        project->load(fileName);
-    }
-    catch (QString &err)
-    {
-        project->error(err);
-    }
+    if (!dialog.exec())
+        return;
+
+    QStringList fileNames = dialog.selectedFiles();
+    if (fileNames.isEmpty())
+        return;
+
+    settings->setValue(Settings::SaveDir, dialog.directory().path());
+    settings->setValue(Settings::MainWindow_OpenFileFilter, dialog.selectedNameFilter());
+
+    project->load(fileNames);
 }
 
+
 /************************************************
  *
  ************************************************/
@@ -1454,3 +1476,30 @@ void MainWindow::loadAuto()
         project->error(err);
     }
 }
+
+
+/************************************************
+ *
+ ************************************************/
+void MainWindow::longTaskStarted(const ProjectLongTask *task)
+{
+    QLabel *label = new QLabel(this);
+    QProgressBar *progressBar = new QProgressBar(this);
+    progressBar->setMaximum(0);
+    progressBar->setFixedWidth(100);
+    progressBar->setSizePolicy(mProgressBar.sizePolicy().horizontalPolicy(),
+                               QSizePolicy::Maximum);
+
+
+    label->setText(task->title());
+
+    ui->statusbar->insertWidget(0, label);
+    ui->statusbar->insertWidget(1, progressBar);
+
+    connect(task, &ProjectLongTask::finished, [this, label, progressBar]()
+    {
+        label->deleteLater();
+        progressBar->deleteLater();
+    });
+
+}
