@@ -33,15 +33,19 @@
 #include <QStringList>
 #include <QList>
 #include <QTemporaryFile>
+#include <QUrl>
+#include <QDir>
 
 #define protected public
 #include "../kernel/layout.h"
 #include "../kernel/project.h"
 #include "../kernel/sheet.h"
-#include "../kernel/projectfile.h"
+#include "iofiles/boofile.h"
 #include "../boomagatypes.h"
 #include "../kernel/projectpage.h"
 #include "../settings.h"
+#include "../../common.h"
+
 
 #define COMPARE(actual, expected) \
     do {\
@@ -60,10 +64,16 @@ do {\
  *
  * ***********************************************/
 TestBoomaga::TestBoomaga(QObject *parent):
-    QObject(parent)
+    QObject(parent),
+    mDataDir(TEST_DATA_DIR),
+    mTmpDir(TEST_OUT_DIR)
 {
 }
 
+
+/************************************************
+ *
+ ************************************************/
 void TestBoomaga::initTestCase()
 {
     QTemporaryFile *tmpFile = new QTemporaryFile(this);
@@ -321,109 +331,6 @@ void TestBoomaga::test_RotationType()
 
 }
 
-#ifdef Q_OS_LINUX_
-QString getValue(const QByteArray &data, const QString &key);
-
-/************************************************
- *
- ************************************************/
-void TestBoomaga::test_envInfo_getValue()
-{
-    QFETCH(QByteArray,  data);
-    QFETCH(QString,     key);
-    QFETCH(QString,     expected);
-
-    QString result = getValue(data, key);
-    QCOMPARE(result, expected);
-}
-
-
-/************************************************
- *
- ************************************************/
-void TestBoomaga::test_envInfo_getValue_data()
-{
-    QTest::addColumn<QByteArray>("data");
-    QTest::addColumn<QString>("key");
-    QTest::addColumn<QString>("expected");
-
-    QTest::newRow("01")
-            << QByteArray()
-            << "DISPLAY"
-            << "";
-
-    QTest::newRow("02")
-            << QByteArray("\0")
-            << "DISPLAY"
-            << "";
-
-    QTest::newRow("03")
-            << QByteArray("DISPLAY=:0\0",
-                          11)
-            << "DISPLAY"
-            << ":0";
-
-    QTest::newRow("04")
-            << QByteArray("DISPLAY=:0\0"
-                          "DISPLAY=:1\0",
-                          22)
-            << "DISPLAY"
-            << ":0";
-
-
-    QTest::newRow("05")
-            << QByteArray("WAYLAND_DISPLAY=wayland-0\0",
-                          26)
-            << "DISPLAY"
-            << "";
-
-    QTest::newRow("06")
-            << QByteArray("WAYLAND_DISPLAY=wayland-0\0"
-                          "DISPLAY=:1\0",
-                          37)
-            << "DISPLAY"
-            << ":1";
-
-    QTest::newRow("07")
-            << QByteArray("DISPLAY=:1\0"
-                          "WAYLAND_DISPLAY=wayland-0\0",
-                          37)
-            << "DISPLAY"
-            << ":1";
-
-    QTest::newRow("08")
-            << QByteArray("WAYLAND_DISPLAY=wayland-0\0"
-                          "DISPLAY=:1\0"
-                          "WAYLAND_DISPLAY=wayland-1\0",
-                          63)
-            << "DISPLAY"
-            << ":1";
-
-    QTest::newRow("09")
-            << QByteArray("WAYLAND_DISPLAY=wayland-0\0"
-                          "WAYLAND_DISPLAY=wayland-1\0"
-                          "DISPLAY=:1\0",
-                          63)
-            << "DISPLAY"
-            << ":1";
-
-}
-
-#else
-/************************************************
- *
- ************************************************/
-void TestBoomaga::test_envInfo_getValue()
-{
-}
-
-/************************************************
- *
- ************************************************/
-void TestBoomaga::test_envInfo_getValue_data()
-{
-}
-#endif
 
 /************************************************
 
@@ -1069,44 +976,7 @@ void TestBoomaga::test_PagePosition_data()
 /************************************************
  *
  * ***********************************************/
-void TestBoomaga::test_BackendOptions()
-{
-    QString options = QTest::currentDataTag();
-    QFETCH(QString, pagesExpected);
-    pagesExpected = pagesExpected.trimmed();
-
-    BackendOptions opts(options);
-    QString result;
-    for (int i=0; i<opts.pages().count(); ++i)
-    {
-        result += QString("%1 ").arg(opts.pages().at(i));
-    }
-    result = result.trimmed();
-
-    QCOMPARE(result, pagesExpected);
-}
-
-
-/************************************************
- *
- * ***********************************************/
-void TestBoomaga::test_BackendOptions_data()
-{
-    QTest::addColumn<QString>("pagesExpected");
-
-    QTest::newRow("") << "";
-    QTest::newRow("page-ranges=1,2,5") << "0 1 4";
-    QTest::newRow("page-ranges=1-5")  << "0 1 2 3 4";
-    QTest::newRow("page-ranges=17,1-5,22") << "16 0 1 2 3 4 21";
-    QTest::newRow("landscape page-ranges=17,1-5,22 media=A4") << "16 0 1 2 3 4 21";
-
-}
-
-
-/************************************************
- *
- * ***********************************************/
-void TestBoomaga::test_ProjectFilePageSpec()
+void TestBoomaga::test_BooFilePageSpec()
 {
     QString string = QTest::currentDataTag();
     QFETCH(QString, direction);
@@ -1117,19 +987,19 @@ void TestBoomaga::test_ProjectFilePageSpec()
 
     if (direction == ">")
     {
-        ProjectFile::PageSpec spec(string);
+        BooFile::PageSpec spec(string);
 
-        QCOMPARE(spec.pageNum(), pageNum);
-        QCOMPARE(spec.isHidden(), hidden);
-        QCOMPARE((int)spec.rotation(), rotation);
+        QCOMPARE(spec.pageNum, pageNum);
+        QCOMPARE(spec.hidden, hidden);
+        QCOMPARE((int)spec.rotation, rotation);
     }
     else
     {
-        ProjectFile::PageSpec spec(pageNum,
+        BooFile::PageSpec spec(pageNum,
                                    hidden,
                                    (Rotation)rotation,
                                    startBooklet);
-        QString result = spec.asString();
+        QString result = spec.toString();
         QCOMPARE(result, string);
     }
 }
@@ -1138,7 +1008,7 @@ void TestBoomaga::test_ProjectFilePageSpec()
 /************************************************
  *
  * ***********************************************/
-void TestBoomaga::test_ProjectFilePageSpec_data()
+void TestBoomaga::test_BooFilePageSpec_data()
 {
     QTest::addColumn<QString>("direction");
     QTest::addColumn<int>("pageNum");
@@ -1251,4 +1121,64 @@ void TestBoomaga::test_BooklesSplit_data()
 }
 
 
+/************************************************
+ *
+ ************************************************/
+void TestBoomaga::testEscapeString()
+{
+    QFETCH(QString, in);
+    QString escaped  = QString::fromStdString(escapeString(in.toStdString()));
+    QString expected = QUrl::fromPercentEncoding(escaped.toLocal8Bit());
+    QCOMPARE(in, expected);
+}
+
+
+/************************************************
+ *
+ ************************************************/
+void TestBoomaga::testEscapeString_data()
+{
+    QTest::addColumn<QString>("in");
+    QTest::newRow("1") << "";
+    QTest::newRow("2") << "1234567890";
+    QTest::newRow("3") << "Multi\nline";
+    QTest::newRow("3") << " '\"\\\" {}()\t\r\b\x0 ";
+    QTest::newRow("4") << "qwertyuiopasdfghjklzxcvbnm";
+    QTest::newRow("5") << "QWERTYUIOPASDFGHJKLZXCVBNM";
+    QTest::newRow("6") << "`-=;'\\,./";
+    QTest::newRow("7") << "йцукенгшщзхъфывапролджэячсмитьбюё";
+    QTest::newRow("8") << "ЙЦУКЕНГШЩЗХЪФЫВАПРОЛДЖЭЯЧСМИТЬБЮЁ";
+}
+
+
+/************************************************
+ *
+ ************************************************/
+static QString safePath(const QString &path)
+{
+    QString res = path;
+    res = res.replace(' ', '_');
+    res = res.replace('\t', '_');
+    res = res.replace('\n', '_');
+    res = res.replace('/', '_');
+    return res;
+}
+
+
+/************************************************
+ *
+ ************************************************/
+QString TestBoomaga::dir(const QString &subTest)
+{
+    QString test    = QString::fromLocal8Bit(QTest::currentTestFunction());
+    QString subtest = subTest.isEmpty() ? QString::fromLocal8Bit(QTest::currentDataTag()) : subTest;
+
+
+    return QDir::cleanPath(QString("%1/%2/%3")
+                    .arg(TEST_OUT_DIR)
+                    .arg(safePath(test))
+                    .arg(safePath(subtest)));
+}
+
+
 QTEST_GUILESS_MAIN(TestBoomaga)
