@@ -58,6 +58,13 @@
         <translation>Boomaga je vyvíjena &lt;a %1&gt;týmem Boomaga a přispěvateli&lt;/a&gt; na GitHub.</translation>
     </message>
 </context>
+<context>
+    <name>BooFile</name>
+    <message>
+        <source>I can&apos;t write to file &apos;%1&apos;</source>
+        <translation>Nelze zapisovat do souboru &apos;%1&apos;</translation>
+    </message>
+</context>
 <context>
     <name>ConfigDialog</name>
     <message>
@@ -105,6 +112,13 @@
         <translation>Směr zprava doleva</translation>
     </message>
 </context>
+<context>
+    <name>CupsBooFile</name>
+    <message>
+        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
+        <translation>Nelze přečíst soubor &quot;%1&quot;, protože buď tento není podporovaným souborovým typem, nebo protože soubor byl poškozen.</translation>
+    </message>
+</context>
 <context>
     <name>ExportToPdf</name>
     <message>
@@ -174,6 +188,13 @@ Jste si jistý, že jej chcete přepsat?</translation>
         <translation>Název dokumentu.</translation>
     </message>
 </context>
+<context>
+    <name>InFile</name>
+    <message>
+        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
+        <translation>Nelze přečíst soubor &quot;%1&quot;, protože buď tento není podporovaným souborovým typem, nebo protože soubor byl poškozen.</translation>
+    </message>
+</context>
 <context>
     <name>JobListView</name>
     <message>
@@ -516,10 +537,16 @@ Jste si jistý, že jej chcete přepsat?</translation>
     </message>
 </context>
 <context>
-    <name>PdfMerger</name>
+    <name>PostScriptFile</name>
     <message>
-        <source>I can&apos;t write file &quot;%1&quot;</source>
-        <translation>Nelze zapsat soubor &quot;%1&quot;</translation>
+        <source>Converting PostScript to PDF</source>
+        <comment>Progressbar text</comment>
+        <translation>Převést PostScript do PDF</translation>
+    </message>
+    <message>
+        <source>I can&apos;t start gs converter: &quot;%1&quot;</source>
+        <comment>Error message. 'gs' is a command line tool from ghostscript</comment>
+        <translation>Nelze spustit převaděč gs: &quot;%1&quot;</translation>
     </message>
 </context>
 <context>
@@ -652,33 +679,6 @@ Jste si jistý, že jej chcete přepsat?</translation>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation>Nelze zapisovat do souboru &apos;%1&apos;</translation>
     </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
-        <translation>Nelze otevřít soubor &quot;%1&quot; (žádný takový soubor nebo adresář)</translation>
-    </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
-        <translation>Nelze otevřít soubor &quot;%1&quot; (přístup odepřen)</translation>
-    </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot;</source>
-        <translation>Nelze otevřít soubor &quot;%1&quot;</translation>
-    </message>
-    <message>
-        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
-        <translation>Nelze přečíst soubor &quot;%1&quot;, protože buď tento není podporovaným souborovým typem, nebo protože soubor byl poškozen.</translation>
-    </message>
-</context>
-<context>
-    <name>ProjectFile</name>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot;</source>
-        <translation>Nelze otevřít soubor &quot;%1&quot;</translation>
-    </message>
-    <message>
-        <source>I can&apos;t write to file &apos;%1&apos;</source>
-        <translation>Nelze zapisovat do souboru &apos;%1&apos;</translation>
-    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -699,6 +699,26 @@ Jste si jistý, že jej chcete přepsat?</translation>
         <comment>Printer profile default name</comment>
         <translation>Výchozí</translation>
     </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot; (Empty file name)</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation>Nelze otevřít soubor &quot;%1&quot; (prázdný název souboru)</translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation>Nelze otevřít soubor &quot;%1&quot; (žádný takový soubor nebo adresář)</translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation>Nelze otevřít soubor &quot;%1&quot; (přístup odepřen)</translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot;</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation>Nelze otevřít soubor &quot;%1&quot;</translation>
+    </message>
 </context>
 <context>
     <name>Settings</name>
@@ -724,12 +744,6 @@ Jste si jistý, že jej chcete přepsat?</translation>
         <source>I can&apos;t create temporary file &quot;%1&quot;</source>
         <translation>Nelze vytvořit dočasný soubor &quot;%1&quot;</translation>
     </message>
-    <message>
-        <source>Something is wrong. I can't find boomagamerger program.
-Please reinstall me.</source>
-        <translation>Něco je špatně. Nelze najít program boomagamerger.
-Proveďte, prosím, přeinstalaci.</translation>
-    </message>
     <message>
         <source>I can&apos;t read file &apos;%1&apos;</source>
         <translation>Nelze přečíst soubor &apos;%1&apos;</translation>
@@ -738,5 +752,9 @@ Proveďte, prosím, přeinstalaci.</translation>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation>Nelze zapisovat do souboru &apos;%1&apos;</translation>
     </message>
+    <message>
+        <source>I can&apos;t write file &quot;%1&quot;</source>
+        <translation>Nelze zapsat soubor &quot;%1&quot;</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
