@@ -58,6 +58,13 @@
         <translation>Boomaga è sviluppato dal Team &lt;a %1&gt;Boomaga e dai  contributori&lt;/a&gt; su GitHub.</translation>
     </message>
 </context>
+<context>
+    <name>BooFile</name>
+    <message>
+        <source>I can&apos;t write to file &apos;%1&apos;</source>
+        <translation>Non posso scrivere nel file &apos;%1&apos;</translation>
+    </message>
+</context>
 <context>
     <name>ConfigDialog</name>
     <message>
@@ -105,6 +112,13 @@
         <translation>Direzione da destra a sinistra</translation>
     </message>
 </context>
+<context>
+    <name>CupsBooFile</name>
+    <message>
+        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
+        <translation>Non posso leggere il file &quot;%1&quot; perché è un tipo di file non supportato, oppure il file è stato danneggiato.</translation>
+    </message>
+</context>
 <context>
     <name>ExportToPdf</name>
     <message>
@@ -174,6 +188,13 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <translation>Il titolo del documento.</translation>
     </message>
 </context>
+<context>
+    <name>InFile</name>
+    <message>
+        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
+        <translation>Non posso leggere il file &quot;%1&quot; perché è un tipo di file non supportato, oppure il file è stato danneggiato.</translation>
+    </message>
+</context>
 <context>
     <name>JobListView</name>
     <message>
@@ -516,10 +537,16 @@ Sei sicuro di volerlo sovracrivere?</translation>
     </message>
 </context>
 <context>
-    <name>PdfMerger</name>
+    <name>PostScriptFile</name>
     <message>
-        <source>I can&apos;t write file &quot;%1&quot;</source>
-        <translation>Non riesco a scrivere il file &quot;%1&quot;</translation>
+        <source>Converting PostScript to PDF</source>
+        <comment>Progressbar text</comment>
+        <translation>Conversione di PostScript in PDF</translation>
+    </message>
+    <message>
+        <source>I can&apos;t start gs converter: &quot;%1&quot;</source>
+        <comment>Error message. 'gs' is a command line tool from ghostscript</comment>
+        <translation>Non riesco ad avviare il convertitore gs: &quot;%1&quot;</translation>
     </message>
 </context>
 <context>
@@ -652,33 +679,6 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation>Non riesco a scrivere sul file &apos;%1&apos;</translation>
     </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
-        <translation>Non posso aprire il file &quot;%1&quot; (File o cartella non esistenti)</translation>
-    </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
-        <translation>Non posso aprire il file &quot;%1&quot; (Accesso negato)</translation>
-    </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot;</source>
-        <translation>Non posso aprire il file &quot;%1&quot;</translation>
-    </message>
-    <message>
-        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
-        <translation>Non posso leggere il file &quot;%1&quot; perché è un tipo di file non supportato, oppure il file è stato danneggiato.</translation>
-    </message>
-</context>
-<context>
-    <name>ProjectFile</name>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot;</source>
-        <translation>Non posso aprire il file &quot;%1&quot;</translation>
-    </message>
-    <message>
-        <source>I can&apos;t write to file &apos;%1&apos;</source>
-        <translation>Non posso scrivere nel file &apos;%1&apos;</translation>
-    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -699,6 +699,26 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <comment>Printer profile default name</comment>
         <translation>Predefinito</translation>
     </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot; (Empty file name)</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation>Non riesco ad aprire il file &quot;% 1&quot; (nome del file vuoto)</translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation>Non posso aprire il file &quot;%1&quot; (File o cartella non esistenti)</translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation>Non posso aprire il file &quot;%1&quot; (Accesso negato)</translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot;</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation>Non posso aprire il file &quot;%1&quot;</translation>
+    </message>
 </context>
 <context>
     <name>Settings</name>
@@ -724,12 +744,6 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <source>I can&apos;t create temporary file &quot;%1&quot;</source>
         <translation>Non riesco a creare il file temporaneo &quot;%1&quot;</translation>
     </message>
-    <message>
-        <source>Something is wrong. I can't find boomagamerger program.
-Please reinstall me.</source>
-        <translation>Qualcosa non va. Non riesco a trovare il programma boomagamerger. 
-Prego installami di nuovo.</translation>
-    </message>
     <message>
         <source>I can&apos;t read file &apos;%1&apos;</source>
         <translation>Non riesco a leggere il file &apos;%1&apos;</translation>
@@ -738,5 +752,9 @@ Prego installami di nuovo.</translation>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation>Non riesco a scrivere sul file &apos;%1&apos;</translation>
     </message>
+    <message>
+        <source>I can&apos;t write file &quot;%1&quot;</source>
+        <translation>Non riesco a scrivere il file &quot;%1&quot;</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
