@@ -58,6 +58,13 @@
         <translation>Boomaga yra sukurta &lt;a %1&gt;Boomaga komandos ir talkininkų&lt;/a&gt; sistemoje GitHub.</translation>
     </message>
 </context>
+<context>
+    <name>BooFile</name>
+    <message>
+        <source>I can&apos;t write to file &apos;%1&apos;</source>
+        <translation>Nepavyksta rašyti į failą &quot;%1&quot;</translation>
+    </message>
+</context>
 <context>
     <name>ConfigDialog</name>
     <message>
@@ -105,6 +112,13 @@
         <translation>Kryptis iš dešinės į kairę</translation>
     </message>
 </context>
+<context>
+    <name>CupsBooFile</name>
+    <message>
+        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
+        <translation>Negaliu perskaityti failo &quot;%1&quot;, nes arba jis yra nepalaikomo failo tipo, arba jis yra pažeistas.</translation>
+    </message>
+</context>
 <context>
     <name>ExportToPdf</name>
     <message>
@@ -174,6 +188,13 @@ Ar tikrai norite pakeisti šį failą?</translation>
         <translation>Dokumento pavadinimas.</translation>
     </message>
 </context>
+<context>
+    <name>InFile</name>
+    <message>
+        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
+        <translation>Negaliu perskaityti failo &quot;%1&quot;, nes arba jis yra nepalaikomo failo tipo, arba jis yra pažeistas.</translation>
+    </message>
+</context>
 <context>
     <name>JobListView</name>
     <message>
@@ -516,10 +537,16 @@ Ar tikrai norite pakeisti šį failą?</translation>
     </message>
 </context>
 <context>
-    <name>PdfMerger</name>
+    <name>PostScriptFile</name>
     <message>
-        <source>I can&apos;t write file &quot;%1&quot;</source>
-        <translation>Nepavyksta rašyti failo &quot;%1&quot;</translation>
+        <source>Converting PostScript to PDF</source>
+        <comment>Progressbar text</comment>
+        <translation>Konvertuojama PostScript į PDF</translation>
+    </message>
+    <message>
+        <source>I can&apos;t start gs converter: &quot;%1&quot;</source>
+        <comment>Error message. 'gs' is a command line tool from ghostscript</comment>
+        <translation>Nepavyksta paleisti gs konvertavimo įrankį: &quot;%1&quot;</translation>
     </message>
 </context>
 <context>
@@ -652,33 +679,6 @@ Ar tikrai norite pakeisti šį failą?</translation>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation>Negaliu įrašyti į failą &apos;%1&apos;</translation>
     </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
-        <translation>Negaliu atverti failo &quot;%1&quot; (Nėra tokio failo ar katalogo)</translation>
-    </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
-        <translation>Negaliu atverti failo &quot;%1&quot; (Prieiga negalima)</translation>
-    </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot;</source>
-        <translation>Negaliu atverti failo &quot;%1&quot;</translation>
-    </message>
-    <message>
-        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
-        <translation>Negaliu perskaityti failo &quot;%1&quot;, nes arba jis yra nepalaikomo failo tipo, arba jis yra pažeistas.</translation>
-    </message>
-</context>
-<context>
-    <name>ProjectFile</name>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot;</source>
-        <translation>Negaliu atverti failo &quot;%1&quot;</translation>
-    </message>
-    <message>
-        <source>I can&apos;t write to file &apos;%1&apos;</source>
-        <translation>Negaliu įrašyti į failą &apos;%1&apos;</translation>
-    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -699,6 +699,26 @@ Ar tikrai norite pakeisti šį failą?</translation>
         <comment>Printer profile default name</comment>
         <translation>Numatytasis</translation>
     </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot; (Empty file name)</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation>Negaliu atverti failo &quot;%1&quot; (Tuščias failo pavadinimas)</translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation>Negaliu atverti failo &quot;%1&quot; (Nėra tokio failo ar katalogo)</translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation>Negaliu atverti failo &quot;%1&quot; (Prieiga negalima)</translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot;</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation>Nepavyksta atverti failą &quot;%1&quot;</translation>
+    </message>
 </context>
 <context>
     <name>Settings</name>
@@ -724,12 +744,6 @@ Ar tikrai norite pakeisti šį failą?</translation>
         <source>I can&apos;t create temporary file &quot;%1&quot;</source>
         <translation>Negaliu sukurti laikinojo failo &quot;%1&quot;</translation>
     </message>
-    <message>
-        <source>Something is wrong. I can't find boomagamerger program.
-Please reinstall me.</source>
-        <translation>Kažkas blogai. Negaliu rasti programos boomagamerger.
-Prašau mane įdiegti iš naujo.</translation>
-    </message>
     <message>
         <source>I can&apos;t read file &apos;%1&apos;</source>
         <translation>Negaliu perskaityti failo &apos;%1&apos;</translation>
@@ -738,5 +752,9 @@ Prašau mane įdiegti iš naujo.</translation>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation>Negaliu įrašyti į failą &apos;%1&apos;</translation>
     </message>
+    <message>
+        <source>I can&apos;t write file &quot;%1&quot;</source>
+        <translation>Nepavyksta rašyti failą &quot;%1&quot;</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
