@@ -58,6 +58,13 @@
         <translation>Boomaga разрабатывается &lt;a %1&gt;командой Boomaga и помощниками&lt;/a&gt; на GitHub.</translation>
     </message>
 </context>
+<context>
+    <name>BooFile</name>
+    <message>
+        <source>I can&apos;t write to file &apos;%1&apos;</source>
+        <translation>Не получилось записать файл: &quot;%1&quot;</translation>
+    </message>
+</context>
 <context>
     <name>ConfigDialog</name>
     <message>
@@ -105,6 +112,13 @@
         <translation>Располагать справа налево </translation>
     </message>
 </context>
+<context>
+    <name>CupsBooFile</name>
+    <message>
+        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
+        <translation>Не получилось прочитать файл: &quot;%1&quot;, файл испорчен или файлы такого типа не поддерживаются.</translation>
+    </message>
+</context>
 <context>
     <name>ExportToPdf</name>
     <message>
@@ -174,6 +188,13 @@ Are you sure you want to overwrite it?</source>
         <translation>Заголовок документа.</translation>
     </message>
 </context>
+<context>
+    <name>InFile</name>
+    <message>
+        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
+        <translation>Не получилось прочитать файл: &quot;%1&quot;, файл испорчен или файлы такого типа не поддерживаются.</translation>
+    </message>
+</context>
 <context>
     <name>JobListView</name>
     <message>
@@ -516,10 +537,16 @@ Are you sure you want to overwrite it?</source>
     </message>
 </context>
 <context>
-    <name>PdfMerger</name>
+    <name>PostScriptFile</name>
     <message>
-        <source>I can&apos;t write file &quot;%1&quot;</source>
-        <translation>Не получилось записать файл: &quot;%1&quot;</translation>
+        <source>Converting PostScript to PDF</source>
+        <comment>Progressbar text</comment>
+        <translation>Преобразование  PostScript в PDF</translation>
+    </message>
+    <message>
+        <source>I can&apos;t start gs converter: &quot;%1&quot;</source>
+        <comment>Error message. 'gs' is a command line tool from ghostscript</comment>
+        <translation>Не получилось запустить gs: &quot;%1&quot;</translation>
     </message>
 </context>
 <context>
@@ -652,33 +679,6 @@ Are you sure you want to overwrite it?</source>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation>Не получилось записать файл: &quot;%1&quot;</translation>
     </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
-        <translation>Не получилось открыть файл: &quot;%1&quot; (Нет такого файла или директории)</translation>
-    </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
-        <translation>Не получилось открыть файл: &quot;%1&quot; (Доступ запрещен)</translation>
-    </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot;</source>
-        <translation>Не получилось открыть файл: &quot;%1&quot;</translation>
-    </message>
-    <message>
-        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
-        <translation>Не получилось прочитать файл: &quot;%1&quot;, файл испорчен или файлы такого типа не поддерживаются.</translation>
-    </message>
-</context>
-<context>
-    <name>ProjectFile</name>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot;</source>
-        <translation>Не получилось открыть файл: &quot;%1&quot;</translation>
-    </message>
-    <message>
-        <source>I can&apos;t write to file &apos;%1&apos;</source>
-        <translation>Не получилось записать файл: &quot;%1&quot;</translation>
-    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -699,6 +699,26 @@ Are you sure you want to overwrite it?</source>
         <comment>Printer profile default name</comment>
         <translation>По умолчанию</translation>
     </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot; (Empty file name)</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation>Не получилось открыть файл: &quot;%1&quot; (Пустое имя файла)</translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation>Не получилось открыть файл: &quot;%1&quot; (Нет такого файла или директории)</translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation>Не получилось открыть файл: &quot;%1&quot; (Доступ запрещен)</translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot;</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation>Не получилось открыть файл: &quot;%1&quot;</translation>
+    </message>
 </context>
 <context>
     <name>Settings</name>
@@ -724,11 +744,6 @@ Are you sure you want to overwrite it?</source>
         <source>I can&apos;t create temporary file &quot;%1&quot;</source>
         <translation>Не получилось создать временный файл: &quot;%1&quot;</translation>
     </message>
-    <message>
-        <source>Something is wrong. I can't find boomagamerger program.
-Please reinstall me.</source>
-        <translation>Шеф, все пропало! Я не могу найти программу с именем boomagamerger. Попробуй переустановить меня.</translation>
-    </message>
     <message>
         <source>I can&apos;t read file &apos;%1&apos;</source>
         <translation>Не получилось прочитать файл: &quot;%1&quot;</translation>
@@ -737,5 +752,9 @@ Please reinstall me.</source>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation>Не получилось записать файл: &quot;%1&quot;</translation>
     </message>
+    <message>
+        <source>I can&apos;t write file &quot;%1&quot;</source>
+        <translation>Не получилось записать файл: &quot;%1&quot;</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
