@@ -60,6 +60,13 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>BooFile</name>
+    <message>
+        <source>I can&apos;t write to file &apos;%1&apos;</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ConfigDialog</name>
     <message>
@@ -107,6 +114,13 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>CupsBooFile</name>
+    <message>
+        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ExportToPdf</name>
     <message>
@@ -175,6 +189,13 @@ Are you sure you want to overwrite it?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>InFile</name>
+    <message>
+        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>JobListView</name>
     <message>
@@ -517,9 +538,15 @@ Are you sure you want to overwrite it?</source>
     </message>
 </context>
 <context>
-    <name>PdfMerger</name>
+    <name>PostScriptFile</name>
     <message>
-        <source>I can&apos;t write file &quot;%1&quot;</source>
+        <source>Converting PostScript to PDF</source>
+        <comment>Progressbar text</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>I can&apos;t start gs converter: &quot;%1&quot;</source>
+        <comment>Error message. &apos;gs&apos; is a command line tool from ghostscript</comment>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -653,33 +680,6 @@ Are you sure you want to overwrite it?</source>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>ProjectFile</name>
-    <message>
-        <source>I can&apos;t open file &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>I can&apos;t write to file &apos;%1&apos;</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -700,6 +700,26 @@ Are you sure you want to overwrite it?</source>
         <comment>Printer profile default name</comment>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot; (Empty file name)</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>I can&apos;t open file &quot;%1&quot;</source>
+        <comment>Error message. %1 is a file name</comment>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Settings</name>
@@ -725,11 +745,6 @@ Are you sure you want to overwrite it?</source>
         <source>I can&apos;t create temporary file &quot;%1&quot;</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Something is wrong. I can&apos;t find boomagamerger program.
-Please reinstall me.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>I can&apos;t read file &apos;%1&apos;</source>
         <translation type="unfinished"></translation>
@@ -738,5 +753,9 @@ Please reinstall me.</source>
         <source>I can&apos;t write to file &apos;%1&apos;</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>I can&apos;t write file &quot;%1&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
